@@ -38,27 +38,25 @@
 #ifndef __DATAPROTOCOL_H__
 #define __DATAPROTOCOL_H__
 
-#ifdef __WIN_32__
+#ifdef _WIN32
 #include <winsock2.h>
 #include <ws2tcpip.h>
 #endif
 
-#ifndef __WIN_32__
-#include <netinet/in.h> //sockaddr_in{} and other Internet defns
-#include <arpa/inet.h> //inet(3) functions
+#ifndef _WIN32
+#include <arpa/inet.h>  //inet(3) functions
 #include <netdb.h>
+#include <netinet/in.h>  //sockaddr_in{} and other Internet defns
 //#include <tr1/memory> //for shared_ptr
 #endif
 
-#include <iostream>
-
-#include <QThread>
 #include <QHostAddress>
 #include <QMutex>
 #include <QMutexLocker>
+#include <QThread>
+#include <iostream>
 
-class JackTrip; // forward declaration
-
+class JackTrip;  // forward declaration
 
 /** \brief Base class that defines the transmission protocol.
  *
@@ -76,10 +74,10 @@ class JackTrip; // forward declaration
  * Redundancy and forward error correction should be implemented on each
  * Transport protocol, cause they depend on the protocol itself
  *
- * \todo This Class should contain definition of jacktrip header and basic funcionality to obtain
- * local machine IPs and maybe functions to manipulate IPs.
- * Redundancy and forward error correction should be implemented on each
- * Transport protocol, cause they depend on the protocol itself
+ * \todo This Class should contain definition of jacktrip header and basic funcionality to
+ * obtain local machine IPs and maybe functions to manipulate IPs. Redundancy and forward
+ * error correction should be implemented on each Transport protocol, cause they depend on
+ * the protocol itself
  *
  * \todo The transport protocol itself has to be implemented subclassing this class, i.e.,
  * using a TCP or UDP protocol.
@@ -94,81 +92,80 @@ class DataProtocol : public QThread
 {
     Q_OBJECT;
 
-public:
-
+   public:
     //----------ENUMS------------------------------------------
     /// \brief Enum to define packet header types
     enum packetHeaderTypeT {
-        DEFAULT, ///< Default application header
-        JAMLINK, ///< Header to use with Jamlinks
-        EMPTY    ///< Empty Header
+        DEFAULT,  ///< Default application header
+        JAMLINK,  ///< Header to use with Jamlinks
+        EMPTY     ///< Empty Header
     };
 
     /// \brief Enum to define class modes, SENDER or RECEIVER
     enum runModeT {
-        SENDER, ///< Set class as a Sender (send packets)
-        RECEIVER ///< Set class as a Receiver (receives packets)
+        SENDER,   ///< Set class as a Sender (send packets)
+        RECEIVER  ///< Set class as a Receiver (receives packets)
     };
     //---------------------------------------------------------
 
-
     /** \brief The class constructor
-   * \param jacktrip Pointer to the JackTrip class that connects all classes (mediator)
-   * \param runmode Sets the run mode, use either DataProtocol::SENDER or
-   * DataProtocol::RECEIVER
-   * \param headertype packetHeaderTypeT header type to use for packets
-   * \param bind_port Port number to bind for this socket (this is the receive or send port depending on the runmode)
-   * \param peer_port Peer port number (this is the receive or send port depending on the runmode)
-   */
-    DataProtocol(JackTrip* jacktrip,
-                 const runModeT runmode,
-                 int bind_port, int peer_port);
+     * \param jacktrip Pointer to the JackTrip class that connects all classes (mediator)
+     * \param runmode Sets the run mode, use either DataProtocol::SENDER or
+     * DataProtocol::RECEIVER
+     * \param headertype packetHeaderTypeT header type to use for packets
+     * \param bind_port Port number to bind for this socket (this is the receive or send
+     * port depending on the runmode) \param peer_port Peer port number (this is the
+     * receive or send port depending on the runmode)
+     */
+    DataProtocol(JackTrip* jacktrip, const runModeT runmode, int bind_port,
+                 int peer_port);
 
     /// \brief The class destructor
     virtual ~DataProtocol();
 
     /** \brief Implements the thread loop
-   *
-   * Depending on the runmode, with will run a DataProtocol::SENDER thread or
-   * DataProtocol::RECEIVER thread
-   */
+     *
+     * Depending on the runmode, with will run a DataProtocol::SENDER thread or
+     * DataProtocol::RECEIVER thread
+     */
     virtual void run() = 0;
 
     /// \brief Stops the execution of the Thread
-    virtual void stop() {
+    virtual void stop()
+    {
         QMutexLocker lock(&mMutex);
         mStopped = true;
     }
 
     /** \brief Sets the size of the audio part of the packets
-   * \param size_bytes Size in bytes
-   */
-    void setAudioPacketSize(const size_t size_bytes){ mAudioPacketSize = size_bytes; }
+     * \param size_bytes Size in bytes
+     */
+    void setAudioPacketSize(const size_t size_bytes) { mAudioPacketSize = size_bytes; }
 
     /** \brief Get the size of the audio part of the packets
-   * \return size_bytes Size in bytes
-   */
-    size_t getAudioPacketSizeInBites() { return(mAudioPacketSize); }
+     * \return size_bytes Size in bytes
+     */
+    size_t getAudioPacketSizeInBites() { return (mAudioPacketSize); }
 
     /** \brief Set the peer address
-   * \param peerHostOrIP IPv4 number or host name
-   * \todo implement here instead of in the subclass UDP
-   */
+     * \param peerHostOrIP IPv4 number or host name
+     * \todo implement here instead of in the subclass UDP
+     */
     virtual void setPeerAddress(const char* peerHostOrIP) = 0;
 
     /** \brief Set the peer incomming (receiving) port number
-   * \param port Port number
-   * \todo implement here instead of in the subclass UDP
-   */
+     * \param port Port number
+     * \todo implement here instead of in the subclass UDP
+     */
     virtual void setPeerPort(int port) = 0;
 
-    //virtual void getPeerAddressFromFirstPacket(QHostAddress& peerHostAddress,
+    // virtual void getPeerAddressFromFirstPacket(QHostAddress& peerHostAddress,
     //				     uint16_t& port) = 0;
 
-#if defined (__WIN_32__)
-    virtual void setSocket(SOCKET &socket) = 0;
+#if defined(_WIN32)
+    virtual void setSocket(SOCKET& socket) = 0;
 #else
-    virtual void setSocket(int &socket) = 0;
+    virtual void setSocket(int& socket) = 0;
 #endif
 
     struct PktStat {
@@ -178,22 +175,24 @@ public:
         uint32_t revived;
         uint32_t statCount;
     };
-    virtual bool getStats(PktStat*) {return false;}
+    virtual bool getStats(PktStat*) { return false; }
 
-    virtual void setIssueSimulation(double /*loss*/, double /*jitter*/, double /*max_delay*/) {}
-    void setUseRtPriority(bool use) {mUseRtPriority = use;}
+    virtual void setIssueSimulation(double /*loss*/, double /*jitter*/,
+                                    double /*max_delay*/)
+    {
+    }
+    void setUseRtPriority(bool use) { mUseRtPriority = use; }
 
-signals:
+   signals:
 
     void signalError(const char* error_message);
     void signalReceivedConnectionFromPeer();
-    void signalCeaseTransmission(const QString &reason = "");
-
-protected:
+    void signalCeaseTransmission(const QString& reason = QLatin1String(""));
 
+   protected:
     /** \brief Get the Run Mode of the object
-   * \return SENDER or RECEIVER
-   */
+     * \return SENDER or RECEIVER
+     */
     runModeT getRunMode() const { return mRunMode; }
 
     /// Boolean stop the execution of the thread
@@ -204,29 +203,25 @@ protected:
     volatile bool mHasPacketsToReceive;
     QMutex mMutex;
 
+   private:
+    int mLocalPort;           ///< Local Port number to Bind
+    int mPeerPort;            ///< Peer Port number to Bind
+    const runModeT mRunMode;  ///< Run mode, either SENDER or RECEIVER
 
-private:
-
-    int mLocalPort; ///< Local Port number to Bind
-    int mPeerPort; ///< Peer Port number to Bind
-    const runModeT mRunMode; ///< Run mode, either SENDER or RECEIVER
-
-    struct sockaddr_in mLocalIPv4Addr; ///< Local IPv4 Address struct
-    struct sockaddr_in mPeerIPv4Addr; ///< Peer IPv4 Address struct
+    struct sockaddr_in mLocalIPv4Addr;  ///< Local IPv4 Address struct
+    struct sockaddr_in mPeerIPv4Addr;   ///< Peer IPv4 Address struct
 
     /// Number of clients running to check for ports already used
     /// \note Unimplemented, try to find another way to check for used ports
     static int sClientsRunning;
 
-    size_t mAudioPacketSize; ///< Packet audio part size
-
+    size_t mAudioPacketSize;  ///< Packet audio part size
 
     /// \todo check a better way to access the header from the subclasses
-protected:
-    //PacketHeader* mHeader; ///< Packet Header
-    JackTrip* mJackTrip; ///< JackTrip mediator class
+   protected:
+    // PacketHeader* mHeader; ///< Packet Header
+    JackTrip* mJackTrip;  ///< JackTrip mediator class
     bool mUseRtPriority;
-
 };
 
 #endif
