@@ -3,7 +3,7 @@
   JackTrip: A System for High-Quality Audio Network Performance
   over the Internet
 
-  Copyright (c) 2008 Juan-Pablo Caceres, Chris Chafe.
+  Copyright (c) 2008-2021 Juan-Pablo Caceres, Chris Chafe.
   SoundWIRE group at CCRMA, Stanford University.
 
   Permission is hereby granted, free of charge, to any person
@@ -38,49 +38,43 @@
 #ifndef __PROCESSPLUGIN_H__
 #define __PROCESSPLUGIN_H__
 
-#include <jack/jack.h>
 #include <QThread>
 
 /** \brief Interface for the process plugins to add to the JACK callback process in
  * JackAudioInterface
  *
- * This class contains the same methods of the FAUST dsp class. A mydsp class can inherit from
- * this class the same way it inherits from dsp. Subclass should implement all methods
- * except init, which is optional for processing that are sampling rate dependent or
- * that need specific initialization.
+ * This class contains the same methods of the FAUST dsp class. A mydsp class can inherit
+ * from this class the same way it inherits from dsp. Subclass should implement all
+ * methods except init, which is optional for processing that are sampling rate dependent
+ * or that need specific initialization.
  */
-class ProcessPlugin : public QThread
+class ProcessPlugin
 {
-public:
-
+   public:
     /// \brief The Class Constructor
-    ProcessPlugin() {};
+    ProcessPlugin(){};
     /// \brief The Class Destructor
-    virtual ~ProcessPlugin() {};
+    virtual ~ProcessPlugin(){};
 
     /// \brief Return Number of Input Channels
     virtual int getNumInputs() = 0;
     /// \brief Return Number of Output Channels
     virtual int getNumOutputs() = 0;
 
-    //virtual void buildUserInterface(UI* interface) = 0;
+    // virtual void buildUserInterface(UI* interface) = 0;
 
-    virtual char* getName() {
-      char* pluginName { const_cast<char*>(typeid(*this).name()) }; // get name of DERIVED class
-      while (isdigit(*pluginName)) { pluginName++; }
-      return pluginName;
-    }
+    virtual const char* getName() const = 0;  // get name of DERIVED class
 
     /** \brief Do proper Initialization of members and class instances. By default this
-   * initializes the Sampling Frequency. If a class instance depends on the
-   * sampling frequency, it should be initialize here.
-   */
-    virtual void init(int samplingRate) {
-      fSamplingFreq = samplingRate;
-      if (verbose) {
-        char* derivedClassName = getName();
-        printf("%s: init(%d)\n",derivedClassName,samplingRate);
-      }
+     * initializes the Sampling Frequency. If a class instance depends on the
+     * sampling frequency, it should be initialize here.
+     */
+    virtual void init(int samplingRate)
+    {
+        fSamplingFreq = samplingRate;
+        if (verbose) {
+            printf("%s: init(%d)\n", getName(), samplingRate);
+        }
     }
     virtual bool getInited() { return inited; }
     virtual void setVerbose(bool v) { verbose = v; }
@@ -88,9 +82,9 @@ public:
     /// \brief Compute process
     virtual void compute(int nframes, float** inputs, float** outputs) = 0;
 
-protected:
-    int fSamplingFreq; ///< Faust Data member, Sampling Rate
-    bool inited = false;
+   protected:
+    int fSamplingFreq;  ///< Faust Data member, Sampling Rate
+    bool inited  = false;
     bool verbose = false;
 };
 
